@@ -1,13 +1,13 @@
-if (require("rstanarm", quietly = TRUE) && require("brms", quietly = TRUE)) {
+if (require("testthat", quietly = TRUE) && suppressPackageStartupMessages(require("bayestestR", quietly = TRUE)) && require("rstanarm", quietly = TRUE) && require("brms", quietly = TRUE)) {
   test_that("p_direction", {
     set.seed(333)
     x <- bayestestR::distribution_normal(10000, 1, 1)
     pd <- bayestestR::p_direction(x)
-    testthat::expect_equal(as.numeric(pd), 0.842, tolerance = 0.1)
-    testthat::expect_equal(as.numeric(p_direction(x, method = "kernel")), 0.842, tolerance = 0.1)
-    testthat::expect_equal(nrow(p_direction(data.frame(replicate(4, rnorm(100))))), 4)
-    testthat::expect_is(pd, "p_direction")
-    testthat::expect_equal(tail(capture.output(print(pd)), 1), "pd = 84.14%")
+    expect_equal(as.numeric(pd), 0.842, tolerance = 0.1)
+    expect_equal(as.numeric(p_direction(x, method = "kernel")), 0.842, tolerance = 0.1)
+    expect_equal(nrow(p_direction(data.frame(replicate(4, rnorm(100))))), 4)
+    expect_s3_class(pd, "p_direction")
+    expect_equal(tail(capture.output(print(pd)), 1), "Probability of Direction: 0.84")
   })
 
 
@@ -17,8 +17,8 @@ if (require("rstanarm", quietly = TRUE) && require("brms", quietly = TRUE)) {
       m <- insight::download_model("stanreg_merMod_5")
       p <- insight::get_parameters(m, effects = "all")
 
-      testthat::test_that("p_direction", {
-        testthat::expect_equal(
+      test_that("p_direction", {
+        expect_equal(
           p_direction(m, effects = "all")$pd,
           p_direction(p)$pd,
           tolerance = 1e-3
@@ -28,8 +28,8 @@ if (require("rstanarm", quietly = TRUE) && require("brms", quietly = TRUE)) {
       m <- insight::download_model("brms_zi_3")
       p <- insight::get_parameters(m, effects = "all", component = "all")
 
-      testthat::test_that("p_direction", {
-        testthat::expect_equal(
+      test_that("p_direction", {
+        expect_equal(
           p_direction(m, effects = "all", component = "all")$pd,
           p_direction(p)$pd,
           tolerance = 1e-3
@@ -37,4 +37,4 @@ if (require("rstanarm", quietly = TRUE) && require("brms", quietly = TRUE)) {
       })
     }
   }
-}
\ No newline at end of file
+}
